package com.srs.comprehensive.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.srs.comprehensive.domain.CphCarders;

/**
 * 班级干部管理Service接口
 *
 * @author srs
 * @date 2023-09-15
 */
public interface ICphCardersService extends IService<CphCarders> {
    /**
     * 查询班级干部管理
     *
     * @param id 班级干部管理主键
     * @return 班级干部管理
     */
    public CphCarders selectCphCardersById(Long id);

    /**
     * 查询班级干部管理列表
     *
     * @param cphCarders 班级干部管理
     * @return 班级干部管理集合
     */
    List<CphCarders> selectCphCardersList(CphCarders cphCarders);

    /**
     * 新增班级干部管理
     *
     * @param cphCarders 班级干部管理
     * @return 结果
     */
    int insertCphCarders(CphCarders cphCarders);

    /**
     * 修改班级干部管理
     *
     * @param cphCarders 班级干部管理
     * @return 结果
     */
    int updateCphCarders(CphCarders cphCarders);

    /**
     * 批量删除班级干部管理
     *
     * @param ids 需要删除的班级干部管理主键集合
     * @return 结果
     */
    int deleteCphCardersByIds(Long[] ids);

    /**
     * 删除班级干部管理信息
     *
     * @param id 班级干部管理主键
     * @return 结果
     */
    int deleteCphCardersById(Long id);
}
